@@ -122,8 +122,8 @@ Mojo::UserAgent::CookieJar - Cookie jar for HTTP user agents
 
 =head1 DESCRIPTION
 
-L<Mojo::UserAgent::CookieJar> is a minimalistic and relaxed cookie jar for
-HTTP user agents.
+L<Mojo::UserAgent::CookieJar> is a minimalistic and relaxed cookie jar used by
+L<Mojo::UserAgent>.
 
 =head1 ATTRIBUTES
 
@@ -131,8 +131,8 @@ L<Mojo::UserAgent::CookieJar> implements the following attributes.
 
 =head2 C<max_cookie_size>
 
-  my $max_cookie_size = $jar->max_cookie_size;
-  $jar                = $jar->max_cookie_size(4096);
+  my $size = $jar->max_cookie_size;
+  $jar     = $jar->max_cookie_size(4096);
 
 Maximum cookie size in bytes, defaults to C<4096>.
 
@@ -155,7 +155,7 @@ Empty the jar.
 
 =head2 C<extract>
 
-  $jar = $jar->extract($tx);
+  $jar->extract($tx);
 
 Extract response cookies from transaction.
 
@@ -167,7 +167,7 @@ Find L<Mojo::Cookie::Request> objects in the jar for L<Mojo::URL> object.
 
 =head2 C<inject>
 
-  $jar = $jar->inject($tx);
+  $jar->inject($tx);
 
 Inject request cookies into transaction.
 
